# E2C.how website

**An informational website by the Exit to Community Collective.**

This is a Hugo static site that migrated content from the earlier site that was built with a Notion database, with assistance from Claude Code.

## Project Overview

The site documents case studies, legal snippets, and resources related to "Exit to Community"—the practice of converting startups into community ownership and governance.

## How to contribute

To contribute to this project, use the contact form at E2C.how to request edit access to the repository. With such access, the public site automatically updates whenever changes are pushed to the `main` branch of this repository. Changes may be pushed either by:

* Editing files directly via the GUI edit tools at `https://git.medlab.host/e2c/e2c-how/`
* Pushing from a local clone via git

## Key Technical Details

### Site Structure
- **Hugo static site generator** with custom layouts
- **Content in Markdown** with YAML frontmatter
- **Custom CSS styling** with E2C yellow branding (#F4D03F)

### Content Types
- **Case Studies** (`/content/case-studies/`) - 24 case studies with logos and descriptions
- **Legal Snippets** (`/content/legal-snippets/`) - Legal documents and frameworks
- **Resources** (`/content/resources/`) - Media, education, and primer content
- **Main Pages** - Homepage, contact, add-your-story with integrated forms

### Important Files
- `/layouts/_default/baseof.html` - Main template with CSS and header/footer
- `/layouts/_default/list.html` - Card layout for case studies and other listings
- `/layouts/_default/single.html` - Individual page template with logo display
- `/layouts/index.html` - Homepage template (prevents auto-generated cards)
- `/static/img/logos/` - Case study logos (64px on cards, 120px on detail pages)

### Styling Notes
- Uses local Space Grotesk font files (no external Google Fonts dependency)
- Yellow hero section with ribbon background header
- Card-based layout with hover effects
- Responsive design with mobile breakpoints
- Case study logos have white background with padding and borders
- Custom styled contact and story submission forms

### Content Management
- All content files have clean YAML frontmatter (title first, logical ordering)
- Case studies include `image: /img/logos/[filename]` for logos
- Descriptions are full-length (not truncated) on listing pages
- No bold formatting in markdown headers
- Tags are used for categorization (no separate categories field)

### Build/Test Commands
- `hugo server -D` - Development server
- `hugo` - Build static site
- No specific linting commands identified yet

### Recent Work Completed
- Migrated all content from Notion exports
- Added ribbon background to header
- Cleaned up content file structure for human readability
- Added case study logos from external directory
- Fixed layout issues and duplicate content problems
- Removed Decap CMS system
- Implemented responsive card layouts with proper logo sizing
- Created custom styled forms for contact and story submission
- Set up git repository with appropriate .gitignore

## Development

### Local Setup
1. Install Hugo: https://gohugo.io/installation/
2. Clone this repository
3. Run `hugo server -D` for development
4. Visit http://localhost:1313

### Deployment

To deploy changes, simply push them to the `main` branch and they should automatically publish. Deployment occurs through GitLab and Surfer on the MEDLab server, making use of Drew Hornbein's [template](https://git.medlab.host/dhorn/medlab-hugo-template).

## External Dependencies
- Hugo static site generator
- Local font files (Space Grotesk)
- No external CMS or database dependencies

## Future Considerations
- May need to add linting/typecheck commands when identified
- Content updates should maintain the clean YAML structure
- New case studies should follow the established pattern with logos
- Consider adding search functionality if the content grows significantly
